@@ -1,6 +1,8 @@
 import asyncio
 from typing import Any, Dict, Optional
 
+from pydantic import validate_arguments
+
 from ..core import BaseClient
 
 POST_PATH = "/users/{user_uuid}/creditreport"
@@ -43,6 +45,7 @@ class BaseCreditReportResource:
             else:
                 return None
 
+    @validate_arguments
     async def _get(self, user_uuid: str) -> Optional[CreditReport]:
         report_id = await self._create(user_uuid)
         report = await self._get_by_id(user_uuid, report_id)
